diff plugins/logger/logger.js @ 847:a23b7b574ed2

irccd: rename [format] section to [templates], closes #1671
author David Demelier <markand@malikania.fr>
date Wed, 10 Jul 2019 20:10:00 +0200
parents 06cc2f95f479
children 6b65493d97cf
line wrap: on
line diff
--- a/plugins/logger/logger.js	Wed Jul 10 13:39:20 2019 +0200
+++ b/plugins/logger/logger.js	Wed Jul 10 20:10:00 2019 +0200
@@ -33,9 +33,9 @@
 var Util = Irccd.Util;
 
 /**
  * All available formats.
  */
-Plugin.format = {
+Plugin.templates = {
 	"join":         "%H:%M:%S >> #{nickname} joined #{channel}",
 	"kick":         "%H:%M:%S :: #{target} has been kicked by #{nickname} [reason: #{reason}]",
 	"me":           "%H:%M:%S * #{nickname} #{message}",
@@ -75,7 +75,7 @@
 
 	Logger.debug("opening: " + path);
 
-	var str = Util.format(Plugin.format[fmt], args);
+	var str = Util.format(Plugin.templates[fmt], args);
 	var file = new File(path, "a");
 
 	file.write(str + "\n");
@@ -33,9 +33,9 @@
 
 /**
- * All available formats.
+ * All available templates.
  */